/*
The purpose of this script is to organize annual World Economic Outlook (WEO) data for countries who adjust or suspend budget balance rules
Scott Sommers
*/

clear
cd ".\Spreads Data - Covid Era"


import excel WEOApr2022all.xlsx ,  firstrow case(lower)
browse

drop iso
drop az ba bb bc bd be estimatesstartafter
drop j k l m n o p q r s t u v w x y

order weocountrycode country weosubjectcode subjectdescriptor z aa ab ac ad ae af ag ah ai aj ak al am an ao ap aq ar as at au av aw ax ay subjectnotes units scale countryseriesspecificnotes
rename z stat_1996
rename	aa	stat_1997
rename	ab	stat_1998
rename	ac	stat_1999
rename	ad	stat_2000
rename	ae	stat_2001
rename	af	stat_2002
rename	ag	stat_2003
rename	ah	stat_2004
rename	ai	stat_2005
rename	aj	stat_2006
rename	ak	stat_2007
rename	al	stat_2008
rename	am	stat_2009
rename	an	stat_2010
rename	ao	stat_2011
rename	ap	stat_2012
rename	aq	stat_2013
rename	ar	stat_2014
rename	as	stat_2015
rename	at	stat_2016
rename	au	stat_2017
rename	av	stat_2018
rename	aw	stat_2019
rename	ax	stat_2020
rename	ay	stat_2021


keep if country=="Argentina" | country=="Armenia" | country=="Chile" | country=="Denmark" | country=="India" | country=="Israel" | country=="Mexico" | country=="Mongolia" | country=="Panama" | country=="Peru" | country=="Russia" | country=="Spain" | country=="United Kingdom" | country=="Uruguay" 

tab country

keep weocountrycode country weosubjectcode stat_1996 stat_1997 stat_1998 stat_1999 stat_2000 stat_2001 stat_2002 stat_2003 stat_2004 stat_2005 stat_2006 stat_2007 stat_2008 stat_2009 stat_2010 stat_2011 stat_2012 stat_2013 stat_2014 stat_2015 stat_2016 stat_2017 stat_2018 stat_2019 stat_2020 stat_2021

reshape long stat_  , i(country weosubjectcode) j(year)  
reshape wide stat_, i(country year) j(weosubjectcode) string

rename	stat_BCA	BCA
rename	stat_BCA_NGDPD	BCA_NGDPD
rename	stat_GGR	GGR
rename	stat_GGR_NGDP	GGR_NGDP
rename	stat_GGSB	GGSB
rename	stat_GGSB_NPGDP	GGSB_NPGDP
rename	stat_GGX	GGX
rename	stat_GGXCNL	GGXCNL
rename	stat_GGXCNL_NGDP	GGXCNL_NGDP
rename	stat_GGXONLB	GGXONLB
rename	stat_GGXONLB_NGDP	GGXONLB_NGDP
rename	stat_GGXWDG	GGXWDG
rename	stat_GGXWDG_NGDP	GGXWDG_NGDP
rename	stat_GGXWDN	GGXWDN
rename	stat_GGXWDN_NGDP	GGXWDN_NGDP
rename	stat_GGX_NGDP	GGX_NGDP
rename	stat_LE	LE
rename	stat_LP	LP
rename	stat_LUR	LUR
rename	stat_NGAP_NPGDP	NGAP_NPGDP
rename	stat_NGDP	NGDP
rename	stat_NGDPD	NGDPD
rename	stat_NGDPDPC	NGDPDPC
rename	stat_NGDPPC	NGDPPC
rename	stat_NGDPRPC	NGDPRPC
rename	stat_NGDPRPPPPC	NGDPRPPPPC
rename	stat_NGDP_D	NGDP_D
rename	stat_NGDP_FY	NGDP_FY
rename	stat_NGDP_R	NGDP_R
rename	stat_NGDP_RPCH	NGDP_RPCH
rename	stat_NGSD_NGDP	NGSD_NGDP
rename	stat_NID_NGDP	NID_NGDP
rename	stat_PCPI	PCPI
rename	stat_PCPIE	PCPIE
rename	stat_PCPIEPCH	PCPIEPCH
rename	stat_PCPIPCH	PCPIPCH
rename	stat_PPPEX	PPPEX
rename	stat_PPPGDP	PPPGDP
rename	stat_PPPPC	PPPPC
rename	stat_PPPSH	PPPSH
rename	stat_TMG_RPCH	TMG_RPCH
rename	stat_TM_RPCH	TM_RPCH
rename	stat_TXG_RPCH	TXG_RPCH
rename	stat_TX_RPCH	TX_RPCH
replace GGXONLB_NGDP="n/a" if GGXONLB_NGDP=="--"

local varlist BCA BCA_NGDPD GGR GGR_NGDP GGSB GGSB_NPGDP GGX GGXCNL GGXCNL_NGDP GGXONLB GGXONLB_NGDP  GGXWDG GGXWDG_NGDP GGXWDN GGXWDN_NGDP GGX_NGDP LE LP LUR NGAP_NPGDP NGDP NGDPD NGDPDPC NGDPPC NGDPRPC NGDPRPPPPC NGDP_D NGDP_FY NGDP_R NGDP_RPCH NGSD_NGDP NID_NGDP PCPI PCPIE PCPIEPCH PCPIPCH PPPEX PPPGDP PPPPC PPPSH TMG_RPCH TM_RPCH TXG_RPCH TX_RPCH
foreach v of local varlist{
destring `v', generate(`v'_clean) ignore("N/A" "n/a"  )
drop  `v'
rename `v'_clean `v'
} 

  
gen  overall_balance = GGXCNL_NGDP

*gen overall_balance_excld_ff_grants  = GGXOFB-GGRG 
*gen overall_balance_excld_oil_rev= GGXOFB-TXGO
gen overall_balance_excld_investment= GGXCNL_NGDP-(NID_NGDP/100)
gen primary_balance= GGXONLB_NGDP
*gen primary_balance_excld_oil_rev= GGXONLB-TXGO
gen primary_balance_excld_invest= GGXONLB_NGDP-(NID_NGDP/100)
*gen cyclically_adj_prim_bal= GGCBP
gen structural_primary_balance= GGSB_NPGDP
*gen structural_overall_balance= GGSBP-GGEI

order  weocountrycode country year  primary_balance overall_balance overall_balance_excld_investment primary_balance_excld_invest structural_primary_balance


***Pull fiscal balance of interest for each country:
 gen key_fiscal_balance=.
replace key_fiscal_balance=overall_balance_excld_investment  if country=="Argentina"
replace key_fiscal_balance=overall_balance  if country=="Armenia"
replace key_fiscal_balance=structural_primary_balance  if country=="Chile"
replace key_fiscal_balance=structural_primary_balance  if country=="Denmark"
replace key_fiscal_balance=primary_balance  if country=="India"
replace key_fiscal_balance=overall_balance  if country=="Israel"
replace key_fiscal_balance=overall_balance_excld_investment  if country=="Mexico"
replace key_fiscal_balance=overall_balance  if country=="Mongolia"
replace key_fiscal_balance=overall_balance_excld_investment  if country=="Panama"
replace key_fiscal_balance=overall_balance_excld_investment  if country=="Peru"
replace key_fiscal_balance=primary_balance_excld_invest  if country=="Russia"
replace key_fiscal_balance=structural_primary_balance  if country=="Spain"
replace key_fiscal_balance=overall_balance  if country=="United Kingdom"
replace key_fiscal_balance=primary_balance  if country=="Uruguay"

replace key_fiscal_balance=key_fiscal_balance*-1

tab key_fiscal_balance  
order weocountrycode country year key_fiscal_balance primary_balance overall_balance overall_balance_excld_investment primary_balance_excld_invest structural_primary_balance

sort key_fiscal_balance country year
sort country year

 
destring  weocountrycode, generate(weocountrycode_clean) ignore("N/A" "n/a" "--")
drop  weocountrycode
rename weocountrycode_clean weocountrycode
 

xtset weocountrycode  year

generate year_adjustment_suspension=.
replace year_adjustment_suspension=2009   if country=="Argentina"
replace year_adjustment_suspension=2009   if country=="Armenia"
replace year_adjustment_suspension=2009  if country=="Chile"
replace year_adjustment_suspension=2009   if country=="Denmark"
replace year_adjustment_suspension=2009   if country=="India"
replace year_adjustment_suspension=2009   if country=="Israel"
replace year_adjustment_suspension=2010   if country=="Mexico"
replace year_adjustment_suspension=2015   if country=="Mongolia"
replace year_adjustment_suspension=2004   if country=="Panama"
replace year_adjustment_suspension=2009   if country=="Peru"
replace year_adjustment_suspension=2009   if country=="Russia"
replace year_adjustment_suspension=2008   if country=="Spain"
replace year_adjustment_suspension=2009   if country=="United Kingdom"
replace year_adjustment_suspension=2009   if country=="Uruguay"


generate prior_avg_5yrs = (L1.key_fiscal_balance + L2.key_fiscal_balance + L3.key_fiscal_balance + L4.key_fiscal_balance + L5.key_fiscal_balance) / 5
generate prior_avg_3yrs = (L1.key_fiscal_balance + L2.key_fiscal_balance + L3.key_fiscal_balance) / 3

order weocountrycode country year year_adjustment_suspension prior_avg_5yrs prior_avg_3yrs key_fiscal_balance primary_balance overall_balance overall_balance_excld_investment primary_balance_excld_invest structural_primary_balance
save Analysis_Table_Event_Study_0, replace


*For each country, flag what the 3-year average was at t=0 (then track deviations from this over time)
gen prior_avg_3_yrs_in_t0=.
replace prior_avg_3_yrs_in_t0=prior_avg_3yrs if year==year_adjustment_suspension
keep country prior_avg_3_yrs_in_t0
drop if missing(prior_avg_3_yrs_in_t0)

save LU_Avg_at_t0, replace

*Join average at t=0 back into main analysis table
use Analysis_Table_Event_Study_0, replace
 merge m:1 country   using LU_Avg_at_t0 
 drop _merge

 save Analysis_Table_Event_Study_1, replace
 
*Method #1: Deviation from Long Term Average, normalized so that t-1=0 
use Analysis_Table_Event_Study_1, replace
gen deviation=key_fiscal_balance-prior_avg_3_yrs_in_t0
gen deviation_t_minus_1=.
replace deviation_t_minus_1=deviation if year==year_adjustment_suspension-1
keep country deviation_t_minus_1
drop if missing(deviation_t_minus_1)
save LU_t_minus_1, replace

*Create Normalized Bechmark Field for year t-1
 use Analysis_Table_Event_Study_1, replace
 merge m:1 country   using LU_t_minus_1 
 drop _merge
 gen deviation=key_fiscal_balance-prior_avg_3_yrs_in_t0
 gen deviation_normalized=deviation-deviation_t_minus_1
 gen event_time=year-year_adjustment_suspension
 
order  country year event_time deviation_normalized  year_adjustment_suspension key_fiscal_balance prior_avg_3_yrs_in_t0 deviation   prior_avg_5yrs prior_avg_3yrs  primary_balance overall_balance overall_balance_excld_investment primary_balance_excld_invest structural_primary_balance weocountrycode
sort country year
****Now I can see everything
save initial_event_study_initial_summary_analysis, replace 

keep country year event_time deviation_normalized deviation weocountrycode
gen t_minus_3=0
gen t_minus_2=0
gen t_minus_1=0
gen t_0=0
gen t_plus_1=0
gen t_plus_2=0
gen t_plus_3=0
gen t_plus_4=0
gen t_plus_5=0
gen t_plus_6=0
gen t_plus_7=0
 
replace t_minus_3=1   if event_time==-3
replace t_minus_2=1  if event_time==-2
replace t_minus_1=1  if event_time==-1
replace t_0=1  if event_time==0
replace t_plus_1=1  if event_time==1
replace t_plus_2=1  if event_time==2
replace t_plus_3=1  if event_time==3
replace t_plus_4=1  if event_time==4
replace t_plus_5=1  if event_time==5
replace t_plus_6=1    if event_time==6 
replace t_plus_7=1    if event_time== 7

 
drop if year<2000
drop if year>2019
 
save initial_event_study_empirical_analysis, replace 


*Initial Summary Analysis:
use initial_event_study_initial_summary_analysis, replace 
drop if  event_time<0

***BBR Duration of spell:
gen flag_back_to_trend=0
replace flag_back_to_trend=1 if deviation<1
keep  country year event_time deviation_normalized deviation flag_back_to_trend
keep if flag_back_to_trend==1
by country: egen year_back_to_trend=min(year)
keep country year_back_to_trend
bysort country year_back_to_trend: keep if _n==1
save LU_year_back_to_trend, replace
 
 use initial_event_study_initial_summary_analysis, replace 
keep  country year event_time deviation_normalized deviation  
merge m:1 country using LU_year_back_to_trend
keep if year==year_back_to_trend
egen p50 = pctile(event_time), p(50)
gen count=1
egen sum_time_back_to_trend=sum(event_time) 
egen count_all=sum(count)
gen avg_time_back_to_trend=sum_time_back_to_trend/count_all
egen min_time_back_to_trend=min(event_time)
keep avg_time_back_to_trend min_time_back_to_trend p50
keep if _n==1
order min_time_back_to_trend  avg_time_back_to_trend p50
save Results_BBR_Duration, replace

*BBR Amplitude:
 use initial_event_study_initial_summary_analysis, replace 
keep  country year event_time deviation_normalized deviation  
merge m:1 country using LU_year_back_to_trend
drop _merge
*drop if year_back_to_trend==.
drop if event_time<0
drop if year>year_back_to_trend
bysort country: egen amplitude=max(deviation)
bysort country:keep if _n==1
keep country amplitude
gen count=1
egen sum_amplitude=sum(amplitude) 
egen count_all=sum(count)
gen avg_amplitude=sum_amplitude/count_all
egen min_amplitude=min(amplitude)
egen max_amplitude=max(amplitude)
sort amplitude
egen p50 = pctile(amplitude), p(50)


keep  avg_amplitude p50 min_amplitude max_amplitude
order min_amplitude avg_amplitude p50 max_amplitude
keep if _n==1 
save Results_BBR_Amplitude, replace




 
*Empirical Analysis:

use initial_event_study_empirical_analysis, replace 
 
cd ".."
 xi: xtgls deviation_normalized t_minus_3 t_minus_2 t_minus_1 t_0 t_plus_1 t_plus_2 t_plus_3 t_plus_4 t_plus_5	i.country i.year 
 #delimit cr
*Then storing the estimates
estimates store leads_lags
*Finally plotting the event study graph using coefplot
#delimit ;
coefplot leads_lags, keep(t_minus_3  t_minus_2  t_minus_1 t_0 t_plus_1 t_plus_2 t_plus_3 t_plus_4 t_plus_5)
coeflabels(t_minus_3 = "-3" t_minus_2="-2"  t_minus_1="-1" t_0="0" t_plus_1="1" t_plus_2="2" t_plus_3="3" t_plus_4="4" t_plus_5="5" )
vertical  
         xtitle("{stSerif:Years Since Adjustment or Suspension to Budget Balance Rule is Made}" ,size(small)) xscale(titlegap(2))  
         ytitle("{stSerif:Deviation of Fiscal Balance (as % GDP) from Long Term Average}" ,size(small))  
		 graphregion(fcolor(white) lcolor(white) lwidth(vvvthin) ifcolor(white) ilcolor(white)  
ilwidth(vvvthin)) ciopts(lwidth(*1) lcolor(black)) mcolor(black) ;

#delimit cr
graph export ".\Output\Figure_5.png", as(png) replace
 

use ".\Spreads Data - Covid Era\Results_BBR_Duration.dta", replace 
gen Category="Duration (Years)"
order Category min_time_back_to_trend  p50 avg_time_back_to_trend
*There was no max (some countries never returned to compliance in sample)
gen max=. 
rename min_time_back_to_trend Min
rename p50 Median
rename avg_time_back_to_trend Mean
rename max Max
save table_1a_pt1, replace

use ".\Spreads Data - Covid Era\Results_BBR_Amplitude.dta", replace 
gen Category="Amplitude (Deviation from Prior Average as % GDP)"
order Category min_amplitude p50 avg_amplitude  max_amplitude
rename min_amplitude Min
rename p50 Median
rename avg_amplitude Mean
rename max Max
append using table_1a_pt1
sort Min
export delimited using ".\Output\Table A15.csv",   replace


 