/*
Event Study Comparing GDP Growth and Inflation During Crisis Period For Countries With and Without Fiscal Rules
Scott Sommers
July 2022
*/
*ssc install carryforward
* ssc install coefplot
clear
  
*****************************************************************
**Inflation LU
*****************************************************************
clear
 import excel using "LU_Country_Name_Crosswalk.xlsx" ,  firstrow case(lower)
 save LU_countryname_crosswalk, replace

* Inflation - Backfilled With IMF Data
clear
 import excel using "World Bank Inflation 1998 2021 - Backfilled.xlsx" ,  firstrow case(lower)
 browse
 
 replace countryname="Trinidad & Tobago" if countryname=="Trinidad and Tobago"
 replace countryname="Turkey" if countryname=="Turkiye"
 rename countryname country_worldbank
 drop if country_worldbank==""
 merge 1:1 country_worldbank using LU_countryname_crosswalk
  tostring _merge, gen(merge)
 drop if merge=="1"
 drop _merge merge

 
drop seriesname seriescode
drop if country_worldbank=="Venezuela, RB"
 
local varlist 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021
foreach v of local varlist{
destring yr`v', generate(yr`v'_clean) ignore("N/A" "n/a" )
drop yr`v'
rename  yr`v'_clean yr`v'
}




 reshape long yr  , i(country_worldbank countrycode) j(gdp)  
 rename yr inflation
 rename gdp year

drop if year<2014 
drop country_worldbank countrycode  
replace year=year+1
rename inflation inflation_lag_backfilled
save LU_Inflation_Lagged_Backfilled_Fiscal_Risk_Analysis, replace
use LU_Inflation_Lagged_Backfilled_Fiscal_Risk_Analysis, replace


*****************************************************************
**USD LCU Exchange Rate
*****************************************************************
clear
 import excel using "World Bank USD LCU Exchange Rate.xlsx" ,  firstrow case(lower)
 browse
  
 replace countryname="Trinidad & Tobago" if countryname=="Trinidad and Tobago"
 replace countryname="Turkey" if countryname=="Turkiye"
 rename countryname country_worldbank
 drop if country_worldbank==""
 merge 1:1 country_worldbank using LU_countryname_crosswalk
  tostring _merge, gen(merge)
 drop if merge=="1"
 drop _merge merge

 
drop seriesname seriescode
drop if country_worldbank=="Venezuela, RB"
 
local varlist 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021
foreach v of local varlist{
destring yr`v', generate(yr`v'_clean) ignore("N/A" "n/a" )
drop yr`v'
rename  yr`v'_clean yr`v'
}




 reshape long yr  , i(country_worldbank countrycode) j(gdp)  
 rename yr USD_LCU_ER
 rename gdp year

drop if year<2013 
sort year country
bysort year: gen country_id=_n
sort country year
xtset country_id year 
 
 gen USD_LCU_ER_lag=L1.USD_LCU_ER
gen log_change_USD_LCU_ER=log(USD_LCU_ER)-log(USD_LCU_ER_lag)
 gen log_change_USD_LCU_ER_lag=L1.log_change_USD_LCU_ER
drop if year<2015

drop country_worldbank countrycode  
drop USD_LCU_ER USD_LCU_ER_lag
save LU_Change_USD_LCU_ER, replace

*****************************************************************
**Real Effective Exchange Rate
*****************************************************************
clear
 import excel using "World Bank Real Effective Exchange Rate.xlsx" ,  firstrow case(lower)
 browse
  
 replace countryname="Trinidad & Tobago" if countryname=="Trinidad and Tobago"
 replace countryname="Turkey" if countryname=="Turkiye"
 rename countryname country_worldbank
 drop if country_worldbank==""
 merge 1:1 country_worldbank using LU_countryname_crosswalk
  tostring _merge, gen(merge)
 drop if merge=="1"
 drop _merge merge

 
drop seriesname seriescode
drop if country_worldbank=="Venezuela, RB"
 
local varlist 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021
foreach v of local varlist{
destring yr`v', generate(yr`v'_clean) ignore("N/A" "n/a" )
drop yr`v'
rename  yr`v'_clean yr`v'
}




 reshape long yr  , i(country_worldbank countrycode) j(gdp)  
 rename yr Real_Effective_ER
 rename gdp year

drop if year<2013 
sort year country
bysort year: gen country_id=_n
sort country year
xtset country_id year 
 
 gen Real_Effective_ER_lag=L1.Real_Effective_ER
gen log_change_Real_Effective_ER=log(Real_Effective_ER)-log(Real_Effective_ER_lag)
 gen log_change_Real_Effective_ER_lag=L1.log_change_Real_Effective_ER
drop if year<2015

drop country_worldbank countrycode  
drop Real_Effective_ER Real_Effective_ER_lag
save LU_Change_Real_Effective_ER, replace
 


